==> qupzilla_1.6.6.orig.tar.xz: qupzilla-1.6.6.orig/src/lib/tools/closedtabsmanager.cpp <==
/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2010-2013  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#include "closedtabsmanager.h"
#include "webtab.h"
#include "qztools.h"
#include "mainapplication.h"

#include <QWebHistory>
#include <QWebSettings>

ClosedTabsManager::ClosedTabsManager()
{
}

void ClosedTabsManager::saveView(WebTab* tab, int position)
{
    if (mApp->isPrivateSession() || (tab->url().isEmpty() && tab->history()->items().count() == 0)) {
        return;
    }

    Tab closedTab;
    closedTab.url = tab->url();
    closedTab.title = tab->title();
    closedTab.position = position;
    closedTab.history = tab->historyData();

    m_closedTabs.prepend(closedTab);
}

ClosedTabsManager::Tab ClosedTabsManager::getFirstClosedTab()
{
    Tab tab;
    tab.position = -1;

    if (m_closedTabs.count() > 0) {
        tab = m_closedTabs.first();
        m_closedTabs.remove(0);
    }

    return tab;
}

ClosedTabsManager::Tab ClosedTabsManager::getTabAt(int index)
{
    Tab tab;
    tab.position = -1;

    if (QzTools::vectorContainsIndex(m_closedTabs, index)) {
        tab = m_closedTabs.at(index);
        m_closedTabs.remove(index);
    }

    return tab;
}

bool ClosedTabsManager::isClosedTabAvailable()
{
    return (m_closedTabs.count() != 0);
}

void ClosedTabsManager::clearList()
{
    m_closedTabs.clear();
}

QVector<ClosedTabsManager::Tab> ClosedTabsManager::allClosedTabs()
{
    return m_closedTabs;
}

==> qupzilla_1.8.9~dfsg1.orig.tar.xz: qupzilla-1.8.9~dfsg1/src/lib/tools/closedtabsmanager.cpp <==
/* ============================================================
* QupZilla - WebKit based browser
* Copyright (C) 2010-2014  David Rosca <nowrep@gmail.com>
*
* This program is free software: you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation, either version 3 of the License, or
* (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program.  If not, see <http://www.gnu.org/licenses/>.
* ============================================================ */
#include "closedtabsmanager.h"
#include "webtab.h"
#include "qztools.h"
#include "mainapplication.h"

#include <QWebHistory>
#include <QWebSettings>

ClosedTabsManager::ClosedTabsManager()
{
}

void ClosedTabsManager::saveTab(WebTab* tab, int position)
{
    if (mApp->isPrivate()) {
        return;
    }

    // Don't save empty tab
    if (tab->url().isEmpty() && tab->history()->items().count() == 0) {
        return;
    }

    Tab closedTab;
    closedTab.url = tab->url();
    closedTab.title = tab->title();
    closedTab.icon = tab->icon();
    closedTab.position = position;
    closedTab.history = tab->historyData();

    m_closedTabs.prepend(closedTab);
}

bool ClosedTabsManager::isClosedTabAvailable()
{
    return !m_closedTabs.isEmpty();
}

ClosedTabsManager::Tab ClosedTabsManager::takeLastClosedTab()
{
    Tab tab;
    tab.position = -1;

    if (m_closedTabs.count() > 0) {
        tab = m_closedTabs.takeFirst();
    }

    return tab;
}

ClosedTabsManager::Tab ClosedTabsManager::takeTabAt(int index)
{
    Tab tab;
    tab.position = -1;

    QLinkedList<Tab>::iterator it;
    int i = 0;

    for (it = m_closedTabs.begin(); it != m_closedTabs.end(); ++it, ++i) {
        if (i == index) {
            tab = *it;
            m_closedTabs.erase(it);
            break;
        }
    }

    return tab;
}

QLinkedList<ClosedTabsManager::Tab> ClosedTabsManager::allClosedTabs()
{
    return m_closedTabs;
}

void ClosedTabsManager::clearList()
{
    m_closedTabs.clear();
}
